# © 2019 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import _, api, fields, models
from odoo.exceptions import ValidationError


class ResPartneCertification(models.Model):
    _name = "res.partner.certification"
    _description = "Agrément Scop"
    _order = "sequence, name"

    name = fields.Char("Agréments")
    sequence = fields.Integer("Séquence", default=10)
    id_riga = fields.Integer("ID RIGA")
    color = fields.Integer("Couleur Index")


class ScopPartnerCompanyType(models.Model):
    _inherit = "res.partner.company.type"

    id_riga = fields.Integer("ID RIGA")
    is_coop = fields.Boolean("Est un statut coopératif")


class ResPartnerCooperativeForm(models.Model):
    _name = "res.partner.cooperative.form"
    _description = "Forme Coopérative"

    name = fields.Char("Forme Coopérative")
    id_riga = fields.Integer("ID RIGA")

    def _get_lm_form(self):
        type_lm = self.env.ref("cgscop_partner.form_scop")
        type_lamaneur = self.env.ref("cgscop_partner.form_lamaneur")
        type_unionscop = self.env.ref("cgscop_partner.form_unionscop")
        return type_lm + type_lamaneur + type_unionscop


class ResPartnerCreationOrigin(models.Model):
    _name = "res.partner.creation.origin"
    _description = "Creation Origin Scop"
    _parent_name = "parent_id"
    _parent_store = True
    _rec_name = "name"
    _order = "id"

    name = fields.Char("Origine / Sous-Origine", index=True, required=True)
    parent_id = fields.Many2one(
        comodel_name="res.partner.creation.origin",
        string="Origine (parent)",
        index=True,
        ondelete="restrict",
    )
    parent_path = fields.Char(index=True)
    child_ids = fields.One2many(
        comodel_name="res.partner.creation.origin",
        inverse_name="parent_id",
        string="Sous origines",
    )
    id_riga = fields.Integer("ID RIGA")

    @api.constrains("parent_id")
    def _check_origin_recursion(self):
        if not self._check_recursion():
            raise ValidationError(
                _("Vous ne pouvez pas créer des origines récursives.")
            )
        return True


class ResPartnerDissolutionReason(models.Model):
    _name = "res.partner.dissolution.reason"
    _description = "Dissolution Reason"

    name = fields.Char("Motif de Décès")


class ResPartnerMandate(models.Model):
    _name = "res.partner.mandate"
    _description = "Mandat"

    name = fields.Char("Mandat")


class ResPartnerFunctionLst(models.Model):
    _name = "res.partner.function_lst"
    _description = "Fonctions"

    name = fields.Char("Fonction")


class ResPartnerFederation(models.Model):
    _name = "res.partner.federation"
    _description = "Fédérations"

    name = fields.Char("Fédération")


class ScopPartnerNaf(models.Model):
    _inherit = "res.partner.naf"

    secteur_id = fields.Many2one(
        "res.partner.secteur.activite",
        string="Secteur",
        ondelete="restrict",
    )
    id_riga = fields.Integer("ID RIGA")
    federation_id = fields.Many2one(
        "res.partner.federation", string="Fédération", ondelete="restrict"
    )


class ResPartnerOrganizationType(models.Model):
    _name = "res.partner.organization.type"
    _description = "Type of Organization"
    _parent_name = "parent_id"
    _parent_store = True
    _rec_name = "name"
    _order = "id"

    name = fields.Char("Type / Sous-Type", index=True, required=True)
    parent_id = fields.Many2one(
        comodel_name="res.partner.organization.type",
        string="Type (parent)",
        index=True,
        ondelete="cascade",
    )
    parent_path = fields.Char(index=True)
    child_ids = fields.One2many(
        comodel_name="res.partner.organization.type",
        inverse_name="parent_id",
        string="Sous types",
    )
    id_riga = fields.Integer("ID RIGA")

    @api.constrains("parent_id")
    def _check_origin_recursion(self):
        if not self._check_recursion():
            raise ValidationError(_("Vous ne pouvez pas créer des types récursifs."))
        return True


class ResPartnerRgpdOrigin(models.Model):
    _name = "res.partner.rgpd.origin"
    _description = "RGPD Origin"

    name = fields.Char("Origine")


class ResPartnerSegment1(models.Model):
    _name = "res.partner.segment1"
    _description = "Segments 1"
    _rec_name = "name"
    _order = "ur_id, name"

    def _default_ur(self):
        return self.env["res.company"]._ur_default_get()

    name = fields.Char("Nom", index=True, required=True)
    color = fields.Integer(string="ID Couleur")
    id_riga = fields.Integer("ID RIGA")
    ur_id = fields.Many2one(
        "union.regionale",
        string="Union Régionale",
        index=True,
        ondelete="restrict",
        default=_default_ur,
    )


class ResPartnerSegment2(models.Model):
    _name = "res.partner.segment2"
    _description = "Segments 2"
    _rec_name = "name"
    _order = "ur_id, name"

    def _default_ur(self):
        return self.env["res.company"]._ur_default_get()

    name = fields.Char("Nom", index=True, required=True)
    color = fields.Integer(string="ID Couleur")
    id_riga = fields.Integer("ID RIGA")
    ur_id = fields.Many2one(
        "union.regionale",
        string="Union Régionale",
        index=True,
        ondelete="restrict",
        default=_default_ur,
    )


class ResPartnerSegment3(models.Model):
    _name = "res.partner.segment3"
    _description = "Segments 3"
    _rec_name = "name"
    _order = "ur_id, name"

    def _default_ur(self):
        return self.env["res.company"]._ur_default_get()

    name = fields.Char("Nom", index=True, required=True)
    color = fields.Integer(string="ID Couleur")
    id_riga = fields.Integer("ID RIGA")
    ur_id = fields.Many2one(
        "union.regionale",
        string="Union Régionale",
        index=True,
        ondelete="restrict",
        default=_default_ur,
    )


class ResPartnerSegment4(models.Model):
    _name = "res.partner.segment4"
    _description = "Segments 4"
    _rec_name = "name"
    _order = "ur_id, name"

    def _default_ur(self):
        return self.env["res.company"]._ur_default_get()

    name = fields.Char("Nom", index=True, required=True)
    color = fields.Integer(string="ID Couleur")
    id_riga = fields.Integer("ID RIGA")
    ur_id = fields.Many2one(
        "union.regionale",
        string="Union Régionale",
        index=True,
        ondelete="restrict",
        default=_default_ur,
    )


class ResPartnerSecteurActivite(models.Model):
    _name = "res.partner.secteur.activite"
    _description = "Secteurs d'activité"

    name = fields.Char("Secteur")


class ResPartnerFiliere(models.Model):
    _name = "res.partner.filiere"
    _description = "Filières"
    _rec_name = "name"
    _order = "name"

    name = fields.Char("Filière")


class ResPartnerMvtMandate(models.Model):
    _name = "res.partner.mvt.mandate"
    _description = "Mandats du mouvement"
    _rec_name = "name"
    _order = "name"

    name = fields.Char("Mandat")

class ResPartnerMvtVip(models.Model):
    _name = "res.partner.mvt.vip"
    _description = "Etiquettes VIP"
    _rec_name = "name"
    _order = "name"

    name = fields.Char("Etiquette")
